github_action_core library

Classes

AnnotationProperties
Command
Represents a command with properties and a message.
ExitCode
Summary
SummaryImageOptions
SummaryTableCell
SummaryWriteOptions

Constants

EOL → const String
SUMMARY_DOCS_URL → const String
SUMMARY_ENV_VAR → const String

Properties

eol → String
no setter
markdownSummary → Summary
final
summary → Summary
final

Functions

debug(String message) → void
error(dynamic message, {AnnotationProperties? properties = const AnnotationProperties()}) → void
escapeData(dynamic s) → String
Escapes the command data by replacing special characters.
escapeProperty(dynamic s) → String
Escapes the command property by replacing special characters.
exportVariable(String name, dynamic val) → void
getInput(String key, {String? defaultValue, bool required = false, bool trimWhitespace = false}) → String?
getState(String name) → String
group<T>(String name, Future<T> body()) → Future<T>
groupEnd() → void
info(String message) → void
isDebug() → bool
issue(String name, {String message = ''}) → void
Issues a command with a given name and optional message.
issueCommand(String command, Map<String, dynamic> properties, dynamic message) → void
Issues a command to the job step.
issueFileCommand(String command, dynamic message) → void
Issues a file command with a command name and a message.
notice(dynamic message, {AnnotationProperties? properties = const AnnotationProperties()}) → void
prepareKeyValueMessage(String key, dynamic value) → String
Prepares a key-value message with a delimiter for a command.
saveState(String name, dynamic value) → void
setCommandEcho(bool enabled) → void
setFailed(dynamic message) → void
startGroup(String name) → void
toCommandProperties(AnnotationProperties? annotationProperties) → Map<String, dynamic>
Converts the annotation properties to command properties.
toCommandValue(dynamic input) → String
Converts the input to a command value.
toPlatformPath(String pth) → String
toPosixPath(String pth) → String
toWin32Path(String pth) → String
warning(dynamic message, {AnnotationProperties? properties = const AnnotationProperties()}) → void